@import '/bootstrap/scss/bootstrap/mixins/_vendor-prefixes.scss';

@import 'components/_context_selection';
@import 'components/sidebar';
@import 'components/pie_charts';

.navbar-brand {

  // The 114 is a legacy value to push the context-menu over
  padding-right: 114px;
}