@import "bootstrap/variables";
@import "horizon/variables";
@import "/horizon/lib/font-awesome/scss/variables";

/* Custom Variables */
$font-size-base: 16px;
$brand-color: #e95420;
$topbar-link-hover: #ec5b29;
$white: #fff;

$brand-primary: $brand-color;

$nav-active-color: #b83a10;
$nav-hover-color: #e1662f;
