$sidebar-box-shadow-color: #c7c7c7;
$sidebar-box-shadow: -3px 2px 6px -2px $sidebar-box-shadow-color inset, -1px 0 0 0 $sidebar-box-shadow-color inset;
$sidebar-background-color: $table-bg-accent;
$sidebar-active-color: #d93c27;
$sidebar-active-indicator-width: $caret-width-base;
$sidebar-active-box-shadow: -3px 3px 6px -3px;
